summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/formwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/formwindow.cpp')
-rw-r--r--kdevdesigner/designer/formwindow.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kdevdesigner/designer/formwindow.cpp b/kdevdesigner/designer/formwindow.cpp
index 77fb2c3f..b4e681da 100644
--- a/kdevdesigner/designer/formwindow.cpp
+++ b/kdevdesigner/designer/formwindow.cpp
@@ -577,7 +577,7 @@ void FormWindow::handleMousePress( TQMouseEvent *e, TQWidget *w )
switch ( currTool ) {
case POINTER_TOOL:
if ( !isMainContainer( TQT_TQOBJECT(w) ) && qstrcmp( w->name(), "central widget" ) != 0 ) { // press on a child widget
- // if the clicked widget is not in a tqlayout, raise it
+ // if the clicked widget is not in a layout, raise it
if ( !w->parentWidget() || WidgetFactory::layoutType( w->parentWidget() ) == WidgetFactory::NoLayout )
w->raise();
if ( ( e->state() & ControlButton ) ) { // with control pressed, always start rubber band selection
@@ -592,7 +592,7 @@ void FormWindow::handleMousePress( TQMouseEvent *e, TQWidget *w )
if ( !sel ) { // ...and widget no selectted: unselect all
clearSelection( FALSE );
} else { // ...widget selected
// only if widget has a tqlayout (it is a tqlayout meta widget or a laid out container!), unselect its childs
if ( WidgetFactory::layoutType( w ) != WidgetFactory::NoLayout ) {
TQObjectList *l = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
setPropertyShowingBlocked( TRUE );
@@ -958,15 +958,15 @@ void FormWindow::handleMouseRelease( TQMouseEvent *e, TQWidget *w )
if ( wa == it.key()->parentWidget() )
goto make_move_command;
// break tqlayout if necessary
if ( WidgetFactory::layoutType( wa ) != WidgetFactory::NoLayout ) {
if ( TQMessageBox::information( mainWindow(), i18n( "Inserting Widget" ),
i18n( "You tried to insert a widget into the "
- "tqlayout Container Widget '%1'.\n"
+ "layout Container Widget '%1'.\n"
"This is not possible. "
- "In order to insert the widget, the tqlayout of '%1'\n"
+ "In order to insert the widget, the layout of '%1'\n"
"must first be broken.\n"
- "Break the tqlayout or cancel the operation?" ).
+ "Break the layout or cancel the operation?" ).
arg( wa->name() ).
arg( wa->name() ), i18n( "&Break Layout" ), i18n( "&Cancel" ) ) )
goto make_move_command; // cancel
@@ -1067,11 +1067,11 @@ void FormWindow::handleMouseRelease( TQMouseEvent *e, TQWidget *w )
if ( WidgetFactory::layoutType( insertParent ) != WidgetFactory::NoLayout ) {
if ( TQMessageBox::information( mainWindow(), i18n( "Inserting Widget" ),
i18n( "You tried to insert a widget into the "
- "tqlayout Container Widget '%1'.\n"
+ "layout Container Widget '%1'.\n"
"This is not possible. "
- "In order to insert the widget, the tqlayout of '%1'\n"
+ "In order to insert the widget, the layout of '%1'\n"
"must first be broken.\n"
- "Break the tqlayout or cancel the operation?" ).
+ "Break the layout or cancel the operation?" ).
arg( insertParent->name() ).
arg( insertParent->name() ), i18n( "&Break Layout" ), i18n( "&Cancel" ) ) == 0 ) {
breakLayout( insertParent );
@@ -2581,7 +2581,7 @@ void FormWindow::setMainContainer( TQWidget *w )
delete mContainer;
mContainer = w;
insertedWidgets.insert( mContainer, mContainer );
- delete tqlayout();
+ delete layout();
TQHBoxLayout *l = new TQHBoxLayout( this );
l->addWidget( w );
if ( resetPropertyWidget ) {
@@ -592,7 +592,7 @@ void FormWindow::handleMousePress( TQMouseEvent *e, TQWidget *w )
clearSelection( FALSE );
} else { // ...widget selected
- // only if widget has a tqlayout (it is a tqlayout meta widget or a laid out container!), unselect its childs
+ // only if widget has a layout (it is a layout meta widget or a laid out container!), unselect its childs
if ( WidgetFactory::layoutType( w ) != WidgetFactory::NoLayout ) {
TQObjectList *l = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
@@ -958,15 +958,15 @@ void FormWindow::handleMouseRelease( TQMouseEvent *e, TQWidget *w )
if ( wa == it.key()->parentWidget() )
goto make_move_command;
- // break tqlayout if necessary
+ // break layout if necessary
if ( WidgetFactory::layoutType( wa ) != WidgetFactory::NoLayout ) {
if ( TQMessageBox::information( mainWindow(), i18n( "Inserting Widget" ),